==> kipmsg-0.1.1.tar.gz: kipmsg-0.1.1/src/kipmsgutils.h <==
/***************************************************************************
 *   Copyright (C) 2006 by 仁木 邦信                                       *
 *   niki@edic.co.jp   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KIPMSGUTILS_H_
#define _KIPMSGUTILS_H_
#include <kiconloader.h>
extern QString GetPercentageIconName( int percent );
#endif	// _KIPMSGUTILS_H_

==> kipmsg-0.1.8.tar.gz: kipmsg-0.1.8/src/kipmsgutils.h <==
/***************************************************************************
 *   Copyright (C) 2006 by 仁木 邦信                                       *
 *   niki@edic.co.jp   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <time.h>
#ifndef _KIPMSGUTILS_H_
#define _KIPMSGUTILS_H_
#include <kiconloader.h>
extern QString GetPercentageIconName( int percent );
extern QString CreateTimeStringAsCTimeStyle( time_t t );
extern QString CreateTimeString( time_t t );
#endif	// _KIPMSGUTILS_H_
